@@ -78,7 +78,7 @@ const someTechnicalAsset = new TechnicalAsset(model, 'Some Technical Asset', {
     redundant: true,
 });
 
-someTechnicalAsset.processed(someData);
+someTechnicalAsset.process(someData);
 
 const someOtherTechnicalAsset = new TechnicalAsset(model, 'Some Other Technical Asset', {
     description: 'Some Description',
@@ -100,9 +100,9 @@ const someOtherTechnicalAsset = new TechnicalAsset(model, 'Some Other Technical
     redundant: true,
 });
 
-someOtherTechnicalAsset.processed(someData);
+someOtherTechnicalAsset.process(someData);
 
-const someTraffic = someTechnicalAsset.communicatedWith('Some Traffic', someOtherTechnicalAsset, {
+const someTraffic = someTechnicalAsset.communicateWith('Some Traffic', someOtherTechnicalAsset, {
     description: 'Some Description',
     protocol: Protocol.HTTPS,
     authentication: Authentication.NONE,
@@ -113,7 +113,7 @@ const someTraffic = someTechnicalAsset.communicatedWith('Some Traffic', someOthe
     usage: Usage.BUSINESS,
 });
 
-someTraffic.sent(someData);
+someTraffic.send(someData);
 
 project.synth();
 ```
@@ -156,6 +156,85 @@ from ._jsii import *
 import constructs
 
 
+@jsii.enum(jsii_type="cdktg.AnnotationMetadataEntryType")
+class AnnotationMetadataEntryType(enum.Enum):
+    INFO = "INFO"
+    WARN = "WARN"
+    ERROR = "ERROR"
+
+
+class Annotations(metaclass=jsii.JSIIMeta, jsii_type="cdktg.Annotations"):
+    '''Includes API for attaching annotations such as warning messages to constructs.'''
+
+    @jsii.member(jsii_name="of") # type: ignore[misc]
+    @builtins.classmethod
+    def of(cls, scope: constructs.IConstruct) -> "Annotations":
+        '''Returns the annotations API for a construct scope.
+
+        :param scope: The scope.
+        '''
+        return typing.cast("Annotations", jsii.sinvoke(cls, "of", [scope]))
+
+    @jsii.member(jsii_name="addError")
+    def add_error(self, message: builtins.str) -> None:
+        '''Adds an { "error":  } metadata entry to this construct.
+
+        The toolkit will fail synthesis when errors are reported.
+
+        :param message: The error message.
+        '''
+        return typing.cast(None, jsii.invoke(self, "addError", [message]))
+
+    @jsii.member(jsii_name="addInfo")
+    def add_info(self, message: builtins.str) -> None:
+        '''Adds an info metadata entry to this construct.
+
+        The CLI will display the info message when apps are synthesized.
+
+        :param message: The info message.
+        '''
+        return typing.cast(None, jsii.invoke(self, "addInfo", [message]))
+
+    @jsii.member(jsii_name="addWarning")
+    def add_warning(self, message: builtins.str) -> None:
+        '''Adds a warning metadata entry to this construct.
+
+        The CLI will display the warning when an app is synthesized.
+        In a future release the CLI might introduce a --strict flag which
+        will then fail the synthesis if it encounters a warning.
+
+        :param message: The warning message.
+        '''
+        return typing.cast(None, jsii.invoke(self, "addWarning", [message]))
+
+
+class Aspects(metaclass=jsii.JSIIMeta, jsii_type="cdktg.Aspects"):
+    '''Aspects can be applied to CDK tree scopes and can operate on the tree before synthesis.'''
+
+    @jsii.member(jsii_name="of") # type: ignore[misc]
+    @builtins.classmethod
+    def of(cls, scope: constructs.IConstruct) -> "Aspects":
+        '''Returns the ``Aspects`` object associated with a construct scope.
+
+        :param scope: The scope for which these aspects will apply.
+        '''
+        return typing.cast("Aspects", jsii.sinvoke(cls, "of", [scope]))
+
+    @jsii.member(jsii_name="add")
+    def add(self, aspect: "IAspect") -> None:
+        '''Adds an aspect to apply this scope before synthesis.
+
+        :param aspect: The aspect to add.
+        '''
+        return typing.cast(None, jsii.invoke(self, "add", [aspect]))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="all")
+    def all(self) -> typing.List["IAspect"]:
+        '''The list of aspects which were directly applied on this scope.'''
+        return typing.cast(typing.List["IAspect"], jsii.get(self, "all"))
+
+
 class Asset(
     constructs.Construct,
     metaclass=jsii.JSIIAbstractClass,
@@ -535,19 +614,19 @@ class Communication(metaclass=jsii.JSIIMeta, jsii_type="cdktg.Communication"):
 
         jsii.create(self.__class__, self, [id, props])
 
-    @jsii.member(jsii_name="received")
-    def received(self, *assets: "DataAsset") -> None:
+    @jsii.member(jsii_name="receive")
+    def receive(self, *assets: "DataAsset") -> None:
         '''
         :param assets: -
         '''
-        return typing.cast(None, jsii.invoke(self, "received", [*assets]))
+        return typing.cast(None, jsii.invoke(self, "receive", [*assets]))
 
-    @jsii.member(jsii_name="sent")
-    def sent(self, *assets: "DataAsset") -> None:
+    @jsii.member(jsii_name="send")
+    def send(self, *assets: "DataAsset") -> None:
         '''
         :param assets: -
         '''
-        return typing.cast(None, jsii.invoke(self, "sent", [*assets]))
+        return typing.cast(None, jsii.invoke(self, "send", [*assets]))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="authentication")
@@ -991,6 +1070,134 @@ class Encryption(enum.Enum):
     ENDUSER_INDIVIDUAL_KEY = "ENDUSER_INDIVIDUAL_KEY"
 
 
+@jsii.interface(jsii_type="cdktg.IAspect")
+class IAspect(typing_extensions.Protocol):
+    '''Represents an Aspect.'''
+
+    @jsii.member(jsii_name="visit")
+    def visit(self, node: constructs.IConstruct) -> None:
+        '''All aspects can visit an IConstruct.
+
+        :param node: -
+        '''
+        ...
+
+
+class _IAspectProxy:
+    '''Represents an Aspect.'''
+
+    __jsii_type__: typing.ClassVar[str] = "cdktg.IAspect"
+
+    @jsii.member(jsii_name="visit")
+    def visit(self, node: constructs.IConstruct) -> None:
+        '''All aspects can visit an IConstruct.
+
+        :param node: -
+        '''
+        return typing.cast(None, jsii.invoke(self, "visit", [node]))
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IAspect).__jsii_proxy_class__ = lambda : _IAspectProxy
+
+
+@jsii.interface(jsii_type="cdktg.IManifest")
+class IManifest(typing_extensions.Protocol):
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="models")
+    def models(self) -> typing.Mapping[builtins.str, "ModelManifest"]:
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="version")
+    def version(self) -> builtins.str:
+        ...
+
+
+class _IManifestProxy:
+    __jsii_type__: typing.ClassVar[str] = "cdktg.IManifest"
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="models")
+    def models(self) -> typing.Mapping[builtins.str, "ModelManifest"]:
+        return typing.cast(typing.Mapping[builtins.str, "ModelManifest"], jsii.get(self, "models"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="version")
+    def version(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "version"))
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IManifest).__jsii_proxy_class__ = lambda : _IManifestProxy
+
+
+@jsii.interface(jsii_type="cdktg.IModelSynthesizer")
+class IModelSynthesizer(typing_extensions.Protocol):
+    @jsii.member(jsii_name="synthesize")
+    def synthesize(self, session: "ISynthesisSession") -> None:
+        '''Synthesize the associated model to the session.
+
+        :param session: -
+        '''
+        ...
+
+
+class _IModelSynthesizerProxy:
+    __jsii_type__: typing.ClassVar[str] = "cdktg.IModelSynthesizer"
+
+    @jsii.member(jsii_name="synthesize")
+    def synthesize(self, session: "ISynthesisSession") -> None:
+        '''Synthesize the associated model to the session.
+
+        :param session: -
+        '''
+        return typing.cast(None, jsii.invoke(self, "synthesize", [session]))
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, IModelSynthesizer).__jsii_proxy_class__ = lambda : _IModelSynthesizerProxy
+
+
+@jsii.interface(jsii_type="cdktg.ISynthesisSession")
+class ISynthesisSession(typing_extensions.Protocol):
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="manifest")
+    def manifest(self) -> "Manifest":
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="outdir")
+    def outdir(self) -> builtins.str:
+        '''The output directory for this synthesis session.'''
+        ...
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="skipValidation")
+    def skip_validation(self) -> typing.Optional[builtins.bool]:
+        ...
+
+
+class _ISynthesisSessionProxy:
+    __jsii_type__: typing.ClassVar[str] = "cdktg.ISynthesisSession"
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="manifest")
+    def manifest(self) -> "Manifest":
+        return typing.cast("Manifest", jsii.get(self, "manifest"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="outdir")
+    def outdir(self) -> builtins.str:
+        '''The output directory for this synthesis session.'''
+        return typing.cast(builtins.str, jsii.get(self, "outdir"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="skipValidation")
+    def skip_validation(self) -> typing.Optional[builtins.bool]:
+        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "skipValidation"))
+
+# Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
+typing.cast(typing.Any, ISynthesisSession).__jsii_proxy_class__ = lambda : _ISynthesisSessionProxy
+
+
 @jsii.enum(jsii_type="cdktg.Integrity")
 class Integrity(enum.Enum):
     ARCHIVE = "ARCHIVE"
@@ -1008,80 +1215,62 @@ class Machine(enum.Enum):
     SERVERLESS = "SERVERLESS"
 
 
+@jsii.implements(IManifest)
 class Manifest(metaclass=jsii.JSIIMeta, jsii_type="cdktg.Manifest"):
-    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
+    def __init__(self, version: builtins.str, outdir: builtins.str) -> None:
         '''
-        :param outdir: The directory to output the threadgile model. Default: - .
+        :param version: -
+        :param outdir: -
         '''
-        props = ManifestProps(outdir=outdir)
+        jsii.create(self.__class__, self, [version, outdir])
 
-        jsii.create(self.__class__, self, [props])
-
-    @jsii.member(jsii_name="fromFile") # type: ignore[misc]
+    @jsii.member(jsii_name="fromPath") # type: ignore[misc]
     @builtins.classmethod
-    def from_file(cls, dir: builtins.str) -> "Manifest":
+    def from_path(cls, dir: builtins.str) -> "Manifest":
         '''
         :param dir: -
         '''
-        return typing.cast("Manifest", jsii.sinvoke(cls, "fromFile", [dir]))
+        return typing.cast("Manifest", jsii.sinvoke(cls, "fromPath", [dir]))
 
-    @jsii.member(jsii_name="addModel")
-    def add_model(self, title: builtins.str, file_path: builtins.str) -> None:
-        '''
-        :param title: -
-        :param file_path: -
-        '''
-        return typing.cast(None, jsii.invoke(self, "addModel", [title, file_path]))
+    @jsii.member(jsii_name="buildManifest")
+    def build_manifest(self) -> IManifest:
+        return typing.cast(IManifest, jsii.invoke(self, "buildManifest", []))
 
-    @jsii.member(jsii_name="save")
-    def save(self) -> None:
-        return typing.cast(None, jsii.invoke(self, "save", []))
+    @jsii.member(jsii_name="forModel")
+    def for_model(self, model: "Model") -> "ModelManifest":
+        '''
+        :param model: -
+        '''
+        return typing.cast("ModelManifest", jsii.invoke(self, "forModel", [model]))
+
+    @jsii.member(jsii_name="writeToFile")
+    def write_to_file(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "writeToFile", []))
+
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="fileName")
+    def FILE_NAME(cls) -> builtins.str:
+        return typing.cast(builtins.str, jsii.sget(cls, "fileName"))
+
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="modelsFolder")
+    def MODELS_FOLDER(cls) -> builtins.str:
+        return typing.cast(builtins.str, jsii.sget(cls, "modelsFolder"))
 
     @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="data")
-    def data(self) -> typing.Mapping[builtins.str, builtins.str]:
-        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "data"))
+    @jsii.member(jsii_name="models")
+    def models(self) -> typing.Mapping[builtins.str, "ModelManifest"]:
+        return typing.cast(typing.Mapping[builtins.str, "ModelManifest"], jsii.get(self, "models"))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="outdir")
     def outdir(self) -> builtins.str:
-        '''The output directory into which models will be synthesized.'''
         return typing.cast(builtins.str, jsii.get(self, "outdir"))
 
-
-@jsii.data_type(
-    jsii_type="cdktg.ManifestProps",
-    jsii_struct_bases=[],
-    name_mapping={"outdir": "outdir"},
-)
-class ManifestProps:
-    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
-        '''
-        :param outdir: The directory to output the threadgile model. Default: - .
-        '''
-        self._values: typing.Dict[str, typing.Any] = {}
-        if outdir is not None:
-            self._values["outdir"] = outdir
-
-    @builtins.property
-    def outdir(self) -> typing.Optional[builtins.str]:
-        '''The directory to output the threadgile model.
-
-        :default: - .
-        '''
-        result = self._values.get("outdir")
-        return typing.cast(typing.Optional[builtins.str], result)
-
-    def __eq__(self, rhs: typing.Any) -> builtins.bool:
-        return isinstance(rhs, self.__class__) and rhs._values == self._values
-
-    def __ne__(self, rhs: typing.Any) -> builtins.bool:
-        return not (rhs == self)
-
-    def __repr__(self) -> str:
-        return "ManifestProps(%s)" % ", ".join(
-            k + "=" + repr(v) for k, v in self._values.items()
-        )
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="version")
+    def version(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "version"))
 
 
 class Model(constructs.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdktg.Model"):
@@ -1115,6 +1304,22 @@ class Model(constructs.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdktg.Mode
 
         jsii.create(self.__class__, self, [project, id, props])
 
+    @jsii.member(jsii_name="isModel") # type: ignore[misc]
+    @builtins.classmethod
+    def is_model(cls, x: typing.Any) -> builtins.bool:
+        '''
+        :param x: -
+        '''
+        return typing.cast(builtins.bool, jsii.sinvoke(cls, "isModel", [x]))
+
+    @jsii.member(jsii_name="addOverride")
+    def add_override(self, path: builtins.str, value: typing.Any) -> None:
+        '''
+        :param path: -
+        :param value: -
+        '''
+        return typing.cast(None, jsii.invoke(self, "addOverride", [path, value]))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="author")
     def author(self) -> Author:
@@ -1140,6 +1345,171 @@ class Model(constructs.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdktg.Mode
     def date(self) -> typing.Optional[datetime.datetime]:
         return typing.cast(typing.Optional[datetime.datetime], jsii.get(self, "date"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="synthesizer")
+    def synthesizer(self) -> IModelSynthesizer:
+        return typing.cast(IModelSynthesizer, jsii.get(self, "synthesizer"))
+
+    @synthesizer.setter
+    def synthesizer(self, value: IModelSynthesizer) -> None:
+        jsii.set(self, "synthesizer", value)
+
+
+@jsii.data_type(
+    jsii_type="cdktg.ModelAnnotation",
+    jsii_struct_bases=[],
+    name_mapping={
+        "construct_path": "constructPath",
+        "level": "level",
+        "message": "message",
+        "stacktrace": "stacktrace",
+    },
+)
+class ModelAnnotation:
+    def __init__(
+        self,
+        *,
+        construct_path: builtins.str,
+        level: AnnotationMetadataEntryType,
+        message: builtins.str,
+        stacktrace: typing.Optional[typing.Sequence[builtins.str]] = None,
+    ) -> None:
+        '''
+        :param construct_path: 
+        :param level: 
+        :param message: 
+        :param stacktrace: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "construct_path": construct_path,
+            "level": level,
+            "message": message,
+        }
+        if stacktrace is not None:
+            self._values["stacktrace"] = stacktrace
+
+    @builtins.property
+    def construct_path(self) -> builtins.str:
+        result = self._values.get("construct_path")
+        assert result is not None, "Required property 'construct_path' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def level(self) -> AnnotationMetadataEntryType:
+        result = self._values.get("level")
+        assert result is not None, "Required property 'level' is missing"
+        return typing.cast(AnnotationMetadataEntryType, result)
+
+    @builtins.property
+    def message(self) -> builtins.str:
+        result = self._values.get("message")
+        assert result is not None, "Required property 'message' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def stacktrace(self) -> typing.Optional[typing.List[builtins.str]]:
+        result = self._values.get("stacktrace")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ModelAnnotation(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+@jsii.data_type(
+    jsii_type="cdktg.ModelManifest",
+    jsii_struct_bases=[],
+    name_mapping={
+        "annotations": "annotations",
+        "construct_path": "constructPath",
+        "name": "name",
+        "sanitized_name": "sanitizedName",
+        "synthesized_model_path": "synthesizedModelPath",
+        "working_directory": "workingDirectory",
+    },
+)
+class ModelManifest:
+    def __init__(
+        self,
+        *,
+        annotations: typing.Sequence[ModelAnnotation],
+        construct_path: builtins.str,
+        name: builtins.str,
+        sanitized_name: builtins.str,
+        synthesized_model_path: builtins.str,
+        working_directory: builtins.str,
+    ) -> None:
+        '''
+        :param annotations: 
+        :param construct_path: 
+        :param name: 
+        :param sanitized_name: 
+        :param synthesized_model_path: 
+        :param working_directory: 
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "annotations": annotations,
+            "construct_path": construct_path,
+            "name": name,
+            "sanitized_name": sanitized_name,
+            "synthesized_model_path": synthesized_model_path,
+            "working_directory": working_directory,
+        }
+
+    @builtins.property
+    def annotations(self) -> typing.List[ModelAnnotation]:
+        result = self._values.get("annotations")
+        assert result is not None, "Required property 'annotations' is missing"
+        return typing.cast(typing.List[ModelAnnotation], result)
+
+    @builtins.property
+    def construct_path(self) -> builtins.str:
+        result = self._values.get("construct_path")
+        assert result is not None, "Required property 'construct_path' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def name(self) -> builtins.str:
+        result = self._values.get("name")
+        assert result is not None, "Required property 'name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def sanitized_name(self) -> builtins.str:
+        result = self._values.get("sanitized_name")
+        assert result is not None, "Required property 'sanitized_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def synthesized_model_path(self) -> builtins.str:
+        result = self._values.get("synthesized_model_path")
+        assert result is not None, "Required property 'synthesized_model_path' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def working_directory(self) -> builtins.str:
+        result = self._values.get("working_directory")
+        assert result is not None, "Required property 'working_directory' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ModelManifest(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
 
 @jsii.data_type(
     jsii_type="cdktg.ModelProps",
@@ -1224,6 +1594,37 @@ class ModelProps:
         )
 
 
+@jsii.implements(IModelSynthesizer)
+class ModelSynthesizer(metaclass=jsii.JSIIMeta, jsii_type="cdktg.ModelSynthesizer"):
+    def __init__(
+        self,
+        model: Model,
+        continue_on_error_annotations: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        '''
+        :param model: -
+        :param continue_on_error_annotations: -
+        '''
+        jsii.create(self.__class__, self, [model, continue_on_error_annotations])
+
+    @jsii.member(jsii_name="synthesize")
+    def synthesize(self, session: ISynthesisSession) -> None:
+        '''Synthesize the associated model to the session.
+
+        :param session: -
+        '''
+        return typing.cast(None, jsii.invoke(self, "synthesize", [session]))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="model")
+    def _model(self) -> Model:
+        return typing.cast(Model, jsii.get(self, "model"))
+
+    @_model.setter
+    def _model(self, value: Model) -> None:
+        jsii.set(self, "model", value)
+
+
 @jsii.data_type(
     jsii_type="cdktg.OutOfScopeProps",
     jsii_struct_bases=[],
@@ -1270,11 +1671,17 @@ class OutOfScopeProps:
 
 
 class Project(constructs.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdktg.Project"):
-    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
+    def __init__(
+        self,
+        *,
+        outdir: typing.Optional[builtins.str] = None,
+        skip_validation: typing.Optional[builtins.bool] = None,
+    ) -> None:
         '''
         :param outdir: The directory to output the threadgile model. Default: - .
+        :param skip_validation: Whether to skip the validation during synthesis of the project. Default: - false
         '''
-        props = ProjectProps(outdir=outdir)
+        props = ProjectProps(outdir=outdir, skip_validation=skip_validation)
 
         jsii.create(self.__class__, self, [props])
 
@@ -1283,26 +1690,45 @@ class Project(constructs.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdktg.Pr
         '''Synthesizes the model to the output directory.'''
         return typing.cast(None, jsii.invoke(self, "synth", []))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="manifest")
+    def manifest(self) -> Manifest:
+        return typing.cast(Manifest, jsii.get(self, "manifest"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="outdir")
     def outdir(self) -> builtins.str:
         '''The output directory into which models will be synthesized.'''
         return typing.cast(builtins.str, jsii.get(self, "outdir"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="skipValidation")
+    def skip_validation(self) -> typing.Optional[builtins.bool]:
+        '''Whether to skip the validation during synthesis of the app.'''
+        return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "skipValidation"))
+
 
 @jsii.data_type(
     jsii_type="cdktg.ProjectProps",
     jsii_struct_bases=[],
-    name_mapping={"outdir": "outdir"},
+    name_mapping={"outdir": "outdir", "skip_validation": "skipValidation"},
 )
 class ProjectProps:
-    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
+    def __init__(
+        self,
+        *,
+        outdir: typing.Optional[builtins.str] = None,
+        skip_validation: typing.Optional[builtins.bool] = None,
+    ) -> None:
         '''
         :param outdir: The directory to output the threadgile model. Default: - .
+        :param skip_validation: Whether to skip the validation during synthesis of the project. Default: - false
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if outdir is not None:
             self._values["outdir"] = outdir
+        if skip_validation is not None:
+            self._values["skip_validation"] = skip_validation
 
     @builtins.property
     def outdir(self) -> typing.Optional[builtins.str]:
@@ -1313,6 +1739,15 @@ class ProjectProps:
         result = self._values.get("outdir")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def skip_validation(self) -> typing.Optional[builtins.bool]:
+        '''Whether to skip the validation during synthesis of the project.
+
+        :default: - false
+        '''
+        result = self._values.get("skip_validation")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1482,8 +1917,8 @@ class TechnicalAsset(Asset, metaclass=jsii.JSIIMeta, jsii_type="cdktg.TechnicalA
 
         jsii.create(self.__class__, self, [model, id, props])
 
-    @jsii.member(jsii_name="communicatedWith")
-    def communicated_with(
+    @jsii.member(jsii_name="communicateWith")
+    def communicate_with(
         self,
         id: builtins.str,
         target: "TechnicalAsset",
@@ -1520,21 +1955,21 @@ class TechnicalAsset(Asset, metaclass=jsii.JSIIMeta, jsii_type="cdktg.TechnicalA
             vpn=vpn,
         )
 
-        return typing.cast(Communication, jsii.invoke(self, "communicatedWith", [id, target, options]))
+        return typing.cast(Communication, jsii.invoke(self, "communicateWith", [id, target, options]))
 
-    @jsii.member(jsii_name="processed")
-    def processed(self, *assets: DataAsset) -> None:
+    @jsii.member(jsii_name="process")
+    def process(self, *assets: DataAsset) -> None:
         '''
         :param assets: -
         '''
-        return typing.cast(None, jsii.invoke(self, "processed", [*assets]))
+        return typing.cast(None, jsii.invoke(self, "process", [*assets]))
 
-    @jsii.member(jsii_name="stored")
-    def stored(self, *assets: DataAsset) -> None:
+    @jsii.member(jsii_name="store")
+    def store(self, *assets: DataAsset) -> None:
         '''
         :param assets: -
         '''
-        return typing.cast(None, jsii.invoke(self, "stored", [*assets]))
+        return typing.cast(None, jsii.invoke(self, "store", [*assets]))
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="assetType")
@@ -1967,6 +2402,9 @@ class OutOfScope(Scope, metaclass=jsii.JSIIMeta, jsii_type="cdktg.OutOfScope"):
 
 
 __all__ = [
+    "AnnotationMetadataEntryType",
+    "Annotations",
+    "Aspects",
     "Asset",
     "AssetProps",
     "AssetType",
@@ -1986,13 +2424,19 @@ __all__ = [
     "DataAssetProps",
     "DataFormat",
     "Encryption",
+    "IAspect",
+    "IManifest",
+    "IModelSynthesizer",
+    "ISynthesisSession",
     "InScope",
     "Integrity",
     "Machine",
     "Manifest",
-    "ManifestProps",
     "Model",
+    "ModelAnnotation",
+    "ModelManifest",
     "ModelProps",
+    "ModelSynthesizer",
     "OutOfScope",
     "OutOfScopeProps",
     "Project",
